# Tkinter Temps
##### *Tkinter Temmps is a package for making Tkinter GUI's with templates*

---

## __Instillation__
    python -m pip install tkinter_temps

## __Classes__

#### *Buttons*
##### ***Classes***
* ##### *Big*
*  * ##### For making big buttons

* ##### *Back*
* * ##### For making back buttons